==> huaweicloudsdkiotanalytics-3.0.79-py2.py3-none-any.whl: huaweicloudsdkiotanalytics/v1/model/list_pipeline_jobs_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPipelineJobsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'pipelines': 'list[PipelineJobInfoDto]'
    }

    attribute_map = {
        'count': 'count',
        'pipelines': 'pipelines'
    }

    def __init__(self, count=None, pipelines=None):
        """ListPipelineJobsResponse - a model defined in huaweicloud sdk"""
        
        super(ListPipelineJobsResponse, self).__init__()

        self._count = None
        self._pipelines = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if pipelines is not None:
            self.pipelines = pipelines

    @property
    def count(self):
        """Gets the count of this ListPipelineJobsResponse.

        总数

        :return: The count of this ListPipelineJobsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListPipelineJobsResponse.

        总数

        :param count: The count of this ListPipelineJobsResponse.
        :type: int
        """
        self._count = count

    @property
    def pipelines(self):
        """Gets the pipelines of this ListPipelineJobsResponse.

        管道列表

        :return: The pipelines of this ListPipelineJobsResponse.
        :rtype: list[PipelineJobInfoDto]
        """
        return self._pipelines

    @pipelines.setter
    def pipelines(self, pipelines):
        """Sets the pipelines of this ListPipelineJobsResponse.

        管道列表

        :param pipelines: The pipelines of this ListPipelineJobsResponse.
        :type: list[PipelineJobInfoDto]
        """
        self._pipelines = pipelines

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPipelineJobsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotanalytics-3.0.94-py2.py3-none-any.whl: huaweicloudsdkiotanalytics/v1/model/list_pipeline_jobs_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPipelineJobsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'pipelines': 'list[PipelineJobInfoDto]'
    }

    attribute_map = {
        'count': 'count',
        'pipelines': 'pipelines'
    }

    def __init__(self, count=None, pipelines=None):
        """ListPipelineJobsResponse

        The model defined in huaweicloud sdk

        :param count: 总数
        :type count: int
        :param pipelines: 管道列表
        :type pipelines: list[:class:`huaweicloudsdkiotanalytics.v1.PipelineJobInfoDto`]
        """
        
        super(ListPipelineJobsResponse, self).__init__()

        self._count = None
        self._pipelines = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if pipelines is not None:
            self.pipelines = pipelines

    @property
    def count(self):
        """Gets the count of this ListPipelineJobsResponse.

        总数

        :return: The count of this ListPipelineJobsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListPipelineJobsResponse.

        总数

        :param count: The count of this ListPipelineJobsResponse.
        :type count: int
        """
        self._count = count

    @property
    def pipelines(self):
        """Gets the pipelines of this ListPipelineJobsResponse.

        管道列表

        :return: The pipelines of this ListPipelineJobsResponse.
        :rtype: list[:class:`huaweicloudsdkiotanalytics.v1.PipelineJobInfoDto`]
        """
        return self._pipelines

    @pipelines.setter
    def pipelines(self, pipelines):
        """Sets the pipelines of this ListPipelineJobsResponse.

        管道列表

        :param pipelines: The pipelines of this ListPipelineJobsResponse.
        :type pipelines: list[:class:`huaweicloudsdkiotanalytics.v1.PipelineJobInfoDto`]
        """
        self._pipelines = pipelines

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPipelineJobsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
